@@ -255,12 +255,17 @@ class Project:
             # Ensure SSH keys have been defined
             if env.ssh_priv_key is None:
                 raise ProjectError("SSH private key not defined")
+            shutil.copy(env.ssh_priv_key.name, self.ssh_priv_key)
+            os.chmod(self.ssh_priv_key, stat.S_IREAD | stat.S_IWRITE)
+
+            if not hasattr(env, 'ssh_pub_key'):
+                # Baremetal does not require public key usage
+                return
+
             if env.ssh_pub_key is None:
                 raise ProjectError("SSH public key not defined")
 
-            shutil.copy(env.ssh_priv_key.name, self.ssh_priv_key)
             shutil.copy(env.ssh_pub_key.name, self.ssh_pub_key)
-            os.chmod(self.ssh_priv_key, stat.S_IREAD | stat.S_IWRITE)
             os.chmod(self.ssh_pub_key, stat.S_IREAD | stat.S_IWRITE)
 
     def _transform_terraform_tpl(self):
@@ -324,7 +329,6 @@ class Project:
             'pooler_type': ra['pooler_type'],
             'postgres_server': {
                 'count': ra['pg_count'],
-                'instance_type': pg['instance_type'],
             },
             'pg_type': env.postgres_type,
             'replication_type': ra['replication_type'],
@@ -1145,7 +1149,7 @@ class Project:
 
         ext_project_ssh_priv_key = project_ssh_priv_key + '.pem'
         os.rename(project_ssh_priv_key, ext_project_ssh_priv_key)
-        if env.reference_architecture == 'EDB-Always-On':
+        if env.reference_architecture.startswith('EDB-Always-On'):
             shutil.copy(project_ssh_pub_key, ext_project_ssh_priv_key + '.pub')
 
         self.custom_ssh_keys[ssh_user] = dict(
@@ -1171,10 +1175,10 @@ class Project:
             if status != 'PROVISIONED':
                 raise ProjectError('Machines not provisioned')
 
-        # Load terraform vars.
-        self._load_terraform_vars()
-        ssh_user = self.terraform_vars['ssh_user']
-        ssh_priv_key = self.terraform_vars['ssh_priv_key']
+        # Get SSH user and key path from ansible vars.
+        self._load_ansible_vars()
+        ssh_user = self.ansible_vars['ssh_user']
+        ssh_priv_key = self.ansible_vars['ssh_priv_key']
 
         # Read ansible inventory
         inventory_data = None
@@ -1292,7 +1296,7 @@ class Project:
         """
 
         # Verify the tpaexec_bin and tpa_subscription_token based on architecture
-        if env.reference_architecture == 'EDB-Always-On':
+        if env.reference_architecture.startswith('EDB-Always-On'):
             if not env.tpaexec_bin or not env.tpa_subscription_token:
                 raise ProjectError(
                          "--tpaexec-bin and --tpaexec-subscription-token "
@@ -1316,7 +1320,7 @@ class Project:
             except Exception as e:
                 raise ProjectError(str(e))
 
-        if env.reference_architecture == 'EDB-Always-On':
+        if env.reference_architecture.startswith('EDB-Always-On'):
             with AM("Copying PoT TPAexec hooks code into %s" % tpaexec_hooks_path):
                 try:
                     shutil.copytree(self.tpaexec_pot_hooks, tpaexec_hooks_path)
@@ -1370,7 +1374,7 @@ class Project:
         # Instances availability checking hook
         exec_hook(self, 'hook_instances_avaiblability', cloud_cli)
 
-        if self.ansible_vars['reference_architecture'] == 'EDB-Always-On':
+        if self.ansible_vars['reference_architecture'].startswith('EDB-Always-On'):
             self.tpaexec_provision()
 
         with AM("SSH configuration"):
@@ -1430,7 +1434,7 @@ class Project:
         # Load ansible vars
         self._load_ansible_vars()
 
-        if self.ansible_vars['reference_architecture'] == 'EDB-Always-On':
+        if self.ansible_vars['reference_architecture'].startswith('EDB-Always-On'):
             self.tpaexec_deploy()
 
         if not no_install_collection:
@@ -1451,7 +1455,8 @@ class Project:
             route53_access_key=self.ansible_vars['route53_access_key'],
             route53_secret=self.ansible_vars['route53_secret'],
             project=self.ansible_vars['project'],
-            public_key=self.ansible_vars['public_key']
+            public_key=self.ansible_vars['public_key'],
+            reference_architecture=self.ansible_vars['reference_architecture']
         )
         if self.ansible_vars.get('pg_data'):
             extra_vars.update(dict(
